@@ -4,7 +4,7 @@ use warnings;
 package Test::Class::MethodInfo;
 use Carp;
 
-our $VERSION = '0.34';
+our $VERSION = '0.40';
 
 sub new {
     my ( $class, %param ) = @_;
@@ -21,6 +21,8 @@ sub new {
 
 sub name { shift->{name} };
 
+sub type { shift->{type} };
+
 sub num_tests	{ 
 	my ( $self, $n ) = @_;
 	if ( defined $n ) {
@@ -76,6 +78,8 @@ Holds info related to particular test methods. Not part of the public API and li
 
 =item B<name>
 
+=item B<type>
+
 =item B<num_tests>
 
 =back
@@ -114,4 +118,4 @@ Copyright 2006 Adrian Howard, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
